@@ -53,8 +53,6 @@
 ;; "ar -p" doesn't seem to work for .deb files on Solaris 2.4 and 2.5.
 ;; It works on Solaris 2.6, SGI's IRIX 6.1 and 6.2, and Linux, of course.
 
-;; deb-view apparently doesn't work with emacs 20.x.
-
 ;; Old-style .deb files require the dpkg-deb program. I don't know how to
 ;; extract control.tar.gz from these deb files, so you only get to see
 ;; the package control file, but nothing else such as the install scripts.
@@ -261,6 +259,11 @@ In dired, press ^d on the dired line of the .deb file to view.
 Or, execute: ESCAPE x deb-view RETURN, and enter the .deb file name
 at the prompt."
   (interactive "fdeb file to view: ")
+  (if (and (or (string-match "Lucid" emacs-version)
+	       (string-match "XEmacs" emacs-version))
+	   (>= emacs-major-version 21))
+      (require 'view-less)
+    (require 'view))
   (require 'view)
   (let* ((info-buffer-name (concat (file-name-nondirectory debfile) "-INFO"))
          (data-buffer-name (concat (file-name-nondirectory debfile) "-DATA"))
@@ -271,6 +274,7 @@ at the prompt."
                                   (kill-buffer (get-buffer data-buffer-name)))
                              (get-buffer-create data-buffer-name)))
          (return-buffer (current-buffer))
+	 (coding-system-for-read 'no-conversion)
 	 file-buffer
          new-archive-format)
     ;; info
@@ -298,6 +302,7 @@ at the prompt."
                                 " control.tar.gz | gzip -cd"))
           (goto-char 1)
           (setq buffer-file-name (concat debfile "-INFO"))
+          (if (fboundp 'set-buffer-multibyte) (set-buffer-multibyte nil))
           (tar-mode)
           (tar-next-line 1)
           (switch-to-buffer info-buffer t))
@@ -322,6 +327,7 @@ at the prompt."
                     (concat "dpkg-deb --fsys-tarfile " debfile)))
     (goto-char 1)
     (setq buffer-file-name (concat debfile "-DATA"))
+    (if (fboundp 'set-buffer-multibyte) (set-buffer-multibyte nil))
     (tar-mode)
     (tar-next-line 1)
     (setq deb-view-dired-view-return-buffer return-buffer)
